wait_for_proven

Function wait_for_proven 

pub async fn wait_for_proven(
    node: &(impl AztecNode + ?Sized),
    receipt: &TxReceipt,
    opts: WaitForProvenOpts,
) -> Result<u64, Error>
Wait until the block containing the given receipt is proven on L1.

Takes a receipt (which must have a block_number) and polls the node until the proven block number >= receipt’s block number. Returns the proven block number on success.