pub struct SimulateOptions {
pub from: AztecAddress,
pub skip_validation: bool,
pub skip_fee_enforcement: bool,
pub auth_witnesses: Vec<AuthWitness>,
pub capsules: Vec<Capsule>,
pub additional_scopes: Vec<AztecAddress>,
pub gas_settings: Option<GasSettings>,
pub fee_execution_payload: Option<ExecutionPayload>,
pub estimate_gas: bool,
pub estimated_gas_padding: Option<f64>,
}Expand description
Options for transaction simulation.
Fields
from: AztecAddressAddress of the simulating account.
skip_validation: boolSkip validation checks during simulation.
skip_fee_enforcement: boolWhether to skip fee enforcement during simulation.
auth_witnesses: Vec<AuthWitness>Additional authorization witnesses.
capsules: Vec<Capsule>Private data capsules for the simulation.
additional_scopes: Vec<AztecAddress>Additional note-discovery scopes.
gas_settings: Option<GasSettings>Gas settings for the simulation.
fee_execution_payload: Option<ExecutionPayload>Pre-resolved fee execution payload to merge into the transaction.
estimate_gas: boolIf true, estimate gas and include suggested gas settings in the result.
estimated_gas_padding: Option<f64>Padding factor for gas estimation (default: 0.1 = 10%).